var gulp = require('gulp'); 

var glob      = require('glob');
var path      = require('path');
var jshint    = require('gulp-jshint');
var sass      = require('gulp-sass');
var concat    = require('gulp-concat');
var uglify    = require('gulp-uglify');
var rename    = require('gulp-rename');
var minifyCSS = require('gulp-minify-css');

// Lint Task
gulp.task('lint', function() {
  return gulp.src('lib/sweet-alert.js')
    .pipe(jshint())
    .pipe(jshint.reporter('default'));
});

// Compile Our Sass
gulp.task('sass', function() {

  gulp.src('example/example.scss')
    .pipe(sass())
    .pipe(rename('example.css'))
    .pipe(gulp.dest('example'));

  return gulp.src(['lib/sweet-alert.scss', 'lib/ie9.css'])
    .pipe(sass())
    .pipe(concat('sweet-alert.css'))
    .pipe(minifyCSS())
    .pipe(gulp.dest('lib'));
});

// Compile theme CSS
var themes = glob.sync('lib/themes/*').map(function(themeDir) {
  console.log(themeDir);
  return path.basename(themeDir);
});

themes.forEach(function(name) {
  gulp.task(name + '-theme', function() {
    return gulp.src('lib/themes/' + name + '/' + name + '.scss')
      .pipe(sass()) // etc
      .pipe(rename(name + '.css'))
      .pipe(gulp.dest('lib/themes/' + name))
  });
});

gulp.task('themes', themes.map(function(name){ return name + '-theme'; }));


// Concatenate & Minify JS
gulp.task('scripts', function() {
  return gulp.src('lib/sweet-alert.js')
    .pipe(gulp.dest('lib'))
    .pipe(rename('sweet-alert.min.js'))
    .pipe(uglify())
    .pipe(gulp.dest('lib'));
});

// Watch Files For Changes
gulp.task('watch', function() {
  gulp.watch('lib/*.js', ['lint', 'scripts']);
  gulp.watch(['lib/*.scss', 'lib/*.css'], ['sass']);
  gulp.watch('lib/themes/*/*.scss', ['themes']);
});

// Default Task
gulp.task('default', ['lint', 'sass', 'scripts', 'watch']);